@@ -3,6 +3,8 @@
 
 #include <string>
 #include <memory>
+#include <vector>
+#include <boost/optional.hpp>
 #include "HttpgdCommons.h"
 
 namespace httpgd
@@ -14,12 +16,14 @@ namespace httpgd
         virtual bool api_remove(int index) = 0;
         virtual bool api_clear() = 0;
 
-        virtual void api_svg(std::ostream &os, int index, double width, double height) = 0;
+        virtual std::string api_svg(int index, double width, double height) = 0;
+        virtual boost::optional<int> api_index(int32_t id) = 0;
 
-        //virtual int api_upid() = 0;
-        //virtual bool api_active() = 0;
-        //virtual int api_page_count() = 0;
         virtual HttpgdState api_state() = 0;
+
+        virtual HttpgdQueryResults api_query_all() = 0;
+        virtual HttpgdQueryResults api_query_index(int index) = 0;
+        virtual HttpgdQueryResults api_query_range(int offset, int limit) = 0;
         
         virtual std::shared_ptr<HttpgdServerConfig> api_server_config() = 0;
     };
