@@ -10,8 +10,8 @@ test_that("rects equivalent regardless of direction", {
   x2 <- xml2::read_xml(hgd_svg())
   dev.off()
 
-  rect1 <- xml2::xml_attrs(xml2::xml_find_all(x1, "./d1:rect")[[2]])
-  rect2 <- xml2::xml_attrs(xml2::xml_find_all(x2, "./d1:rect")[[2]])
+  rect1 <- xml2::xml_attrs(xml2::xml_find_all(x1, "./d1:g/d1:rect")[[1]])
+  rect2 <- xml2::xml_attrs(xml2::xml_find_all(x2, "./d1:g/d1:rect")[[1]])
 
   expect_equal(rect1, rect2)
 })
@@ -23,7 +23,7 @@ test_that("fill and stroke colors", {
     rect(0.2, 0.2, 0.8, 0.8, col = "blue", border = "red")
   })
 
-  rectangle <- xml2::xml_find_all(x, "./d1:rect")[[2]]
+  rectangle <- xml2::xml_find_all(x, "./d1:g/d1:rect")[[1]]
   expect_equal(style_attr(rectangle, "fill"), rgb(0, 0, 1))
   expect_equal(style_attr(rectangle, "stroke"), rgb(1, 0, 0))
 })
\ No newline at end of file
